@@ -1,9 +1,9 @@
 from dataclasses import dataclass
-from typing import List, Optional
+from typing import Optional
 
 from .CartItemPatch import CartItemPatch
 
 
 @dataclass(kw_only=True)
 class ShoppingCartPatch:
-    items: Optional[List[CartItemPatch]] = None
+    items: Optional[list[CartItemPatch]] = None
